@@ -3,18 +3,21 @@ use strict;
 use warnings;
 use namespace::autoclean;
 
-our $VERSION = '0.004007'; # VERSION
+our $VERSION = '0.004008'; # VERSION
 
 use Moose;
 with 'MooseX::Traits';
 
+use MooseX::SetOnce 0.200001;
 use MooseX::StrictConstructor;
 use MooseX::ABC;
 
 has trace => (
 	isa       => 'XML::Compile::SOAP::Trace',
 	predicate => 'has_trace',
-	is        => 'ro',
+	traits    => [ 'SetOnce' ],
+	is        => 'rw',
+	writer    => '_trace',
 );
 
 __PACKAGE__->meta->make_immutable;
@@ -32,7 +35,7 @@ Business::CyberSource::Message - Abstract Message Class;
 
 =head1 VERSION
 
-version 0.004007
+version 0.004008
 
 =head1 ATTRIBUTES
 
