@@ -4,19 +4,21 @@ use strict;
 use warnings;
 use namespace::autoclean;
 
-our $VERSION = '0.004007'; # VERSION
+our $VERSION = '0.004008'; # VERSION
 
 use Moose::Role;
+use MooseX::SetOnce 0.200001;
+
 use MooseX::Types::Moose qw( Bool ArrayRef );
 use MooseX::Types::Common::String 0.001005 qw( NumericCode );
 use MooseX::Types::CyberSource qw( AVSResult );
 
 has ignore_avs_result => (
-	predicate => 'has_ignore_avs_result',
-	required  => 0,
-	is        => 'ro',
 	isa       => Bool,
-	trigger  => sub {
+	predicate => 'has_ignore_avs_result',
+	traits    => ['SetOnce'],
+	is        => 'rw',
+	trigger   => sub {
 		my $self = shift;
 		$self->_request_data->{businessRules}{ignoreAVSResult}
 			= $self->ignore_avs_result ? 'true' : 'false'
@@ -25,11 +27,11 @@ has ignore_avs_result => (
 );
 
 has ignore_cv_result => (
-	predicate => 'has_ignore_cv_result',
-	required  => 0,
-	is        => 'ro',
 	isa       => Bool,
-	trigger  => sub {
+	traits    => ['SetOnce'],
+	is        => 'rw',
+	predicate => 'has_ignore_cv_result',
+	trigger   => sub {
 		my $self = shift;
 		$self->_request_data->{businessRules}{ignoreCVResult}
 			= $self->ignore_cv_result ? 'true' : 'false'
@@ -38,11 +40,11 @@ has ignore_cv_result => (
 );
 
 has ignore_dav_result => (
-	predicate => 'has_ignore_dav_result',
-	required  => 0,
-	is        => 'ro',
 	isa       => Bool,
-	trigger  => sub {
+	traits    => ['SetOnce'],
+	is        => 'rw',
+	predicate => 'has_ignore_dav_result',
+	trigger   => sub {
 		my $self = shift;
 		$self->_request_data->{businessRules}{ignoreDAVResult}
 			= $self->ignore_dav_result ? 'true' : 'false'
@@ -51,11 +53,11 @@ has ignore_dav_result => (
 );
 
 has ignore_export_result => (
-	predicate => 'has_ignore_export_result',
-	required  => 0,
-	is        => 'ro',
 	isa       => Bool,
-	trigger  => sub {
+	traits    => ['SetOnce'],
+	is        => 'rw',
+	predicate => 'has_ignore_export_result',
+	trigger   => sub {
 		my $self = shift;
 		$self->_request_data->{businessRules}{ignoreExportResult}
 			= $self->ignore_export_result ? 'true' : 'false'
@@ -64,11 +66,11 @@ has ignore_export_result => (
 );
 
 has ignore_validate_result => (
-	predicate => 'has_ignore_validate_result',
-	required  => 0,
-	is        => 'ro',
 	isa       => Bool,
-	trigger  => sub {
+	traits    => ['SetOnce'],
+	is        => 'rw',
+	predicate => 'has_ignore_validate_result',
+	trigger   => sub {
 		my $self = shift;
 		$self->_request_data->{businessRules}{ignoreValidateResult}
 			= $self->ignore_validate_result ? 'true' : 'false'
@@ -77,9 +79,9 @@ has ignore_validate_result => (
 );
 
 has decline_avs_flags => (
-	predicate => 'has_decline_avs_flags',
-	required  => 0,
 	isa       => ArrayRef[AVSResult],
+	is        => 'rw',
+	predicate => 'has_decline_avs_flags',
 	traits    => ['Array'],
 	handles   => {
 		_stringify_decline_avs_flags => [ join => ' ' ],
@@ -93,9 +95,10 @@ has decline_avs_flags => (
 );
 
 has score_threshold => (
-	predicate => 'has_score_threshold',
-	required  => 0,
 	isa       => NumericCode,
+	traits    => ['SetOnce'],
+	is        => 'rw',
+	predicate => 'has_score_threshold',
 	trigger  => sub {
 		my $self = shift;
 		$self->_request_data->{businessRules}{scoreThreshold}
@@ -118,7 +121,7 @@ Business::CyberSource::Request::Role::BusinessRules - Business Rules Role
 
 =head1 VERSION
 
-version 0.004007
+version 0.004008
 
 =head1 ATTRIBUTES
 
