@@ -1,14 +1,15 @@
 package Business::CyberSource::Request::Role::CreditCardInfo;
-use 5.008;
 use strict;
 use warnings;
-use Carp;
 use namespace::autoclean;
 
-our $VERSION = '0.004007'; # VERSION
+our $VERSION = '0.004008'; # VERSION
 
 use Moose::Role;
 use MooseX::Aliases;
+use MooseX::SetOnce 0.200001;
+
+
 use MooseX::Types::Moose      qw( Int HashRef );
 use MooseX::Types::CreditCard 0.001001 qw( CreditCard CardSecurityCode );
 use MooseX::Types::CyberSource qw( CvIndicator CardTypeCode _VarcharSixty );
@@ -31,7 +32,6 @@ has credit_card => (
 );
 
 has card_type => (
-	required  => 0,
 	lazy      => 1,
 	predicate => 'has_card_type',
 	is        => 'ro',
@@ -48,8 +48,6 @@ has cc_exp_month => (
 		my $self = shift;
 		$self->_request_data->{card}{expirationMonth} = $self->cc_exp_month;
 	},
-	documentation => 'Two-digit month that the credit card expires '
-		. 'in. Format: MM.',
 );
 
 has cc_exp_year => (
@@ -61,12 +59,9 @@ has cc_exp_year => (
 		my $self = shift;
 		$self->_request_data->{card}{expirationYear} = $self->cc_exp_year;
 	},
-	documentation => 'Four-digit year that the credit card expires in. '
-		. 'Format: YYYY.',
 );
 
 has cv_indicator => (
-	required => 0,
 	init_arg => undef,
 	lazy     => 1,
 	is       => 'ro',
@@ -79,16 +74,15 @@ has cv_indicator => (
 			return 0;
 		}
 	},
-	documentation => 'Flag that indicates whether a CVN code was sent'
 );
 
 has cvn => (
-	required  => 0,
+	isa       => CardSecurityCode,
+	traits    => [ 'SetOnce' ],
 	alias     => [ qw( cvv cvv2  cvc2 cid ) ],
 	predicate => 'has_cvn',
-	is        => 'ro',
-	isa       => CardSecurityCode,
-	trigger  => sub {
+	is        => 'rw',
+	trigger   => sub {
 		my $self = shift;
 		$self->_request_data->{card}{cvNumber} = $self->cvn;
 		$self->_request_data->{card}{cvIndicator} = $self->cv_indicator;
@@ -96,9 +90,9 @@ has cvn => (
 );
 
 has full_name => (
-	required => 0,
-	is       => 'ro',
 	isa      => _VarcharSixty,
+	traits   => [ 'SetOnce' ],
+	is       => 'rw',
 	trigger  => sub {
 		my $self = shift;
 		$self->_request_data->{card}{fullName} = $self->full_name;
@@ -121,7 +115,7 @@ sub _build_card_type {
 		:                                  undef
 		;
 
-	croak $ct . ' card_type was unable to be detected please define it manually'
+	confess $ct . ' card_type was unable to be detected please define it manually'
 		unless $code;
 
 	return $code;
@@ -141,7 +135,7 @@ Business::CyberSource::Request::Role::CreditCardInfo - credit card info role
 
 =head1 VERSION
 
-version 0.004007
+version 0.004008
 
 =head1 ATTRIBUTES
 
@@ -165,9 +159,15 @@ Full Name on the Credit Card
 
 =head2 cc_exp_month
 
+Two-digit month that the credit card expires in. Format: MM
+
 =head2 cc_exp_year
 
-Card's Expiration Year
+Four-digit year that the credit card expires in. Format: YYYY
+
+=head2 cv_indicator
+
+Flag that indicates whether a CVN code was sent
 
 =head1 BUGS
 
