@@ -1,10 +1,9 @@
 package Business::CyberSource::Response::Role::Authorization;
-use 5.008;
 use strict;
 use warnings;
 use namespace::autoclean;
 
-our $VERSION = '0.004007'; # VERSION
+our $VERSION = '0.004008'; # VERSION
 
 use Moose::Role;
 with qw(
@@ -13,21 +12,22 @@ with qw(
 	Business::CyberSource::Response::Role::CVN
 );
 
-use MooseX::Types::Moose   qw( Str     );
+use MooseX::SetOnce 0.200001;
+
 use MooseX::Types::CyberSource qw( _VarcharSeven );
 
 has auth_code => (
-	required  => 0,
-	predicate => 'has_auth_code',
-	is        => 'ro',
 	isa       => _VarcharSeven,
+	predicate => 'has_auth_code',
+	traits    => ['SetOnce'],
+	is        => 'rw',
 );
 
 has auth_record => (
-	required  => 0,
+	isa       => 'Str',
 	predicate => 'has_auth_record',
-	is        => 'ro',
-	isa       => Str,
+	traits    => ['SetOnce'],
+	is        => 'rw',
 );
 
 1;
@@ -44,7 +44,7 @@ Business::CyberSource::Response::Role::Authorization - CyberSource Authorization
 
 =head1 VERSION
 
-version 0.004007
+version 0.004008
 
 =head1 DESCRIPTION
 
