@@ -1,10 +1,9 @@
 package Business::CyberSource::Response::Role::DCC;
-use 5.008;
 use strict;
 use warnings;
 use namespace::autoclean;
 
-our $VERSION = '0.004007'; # VERSION
+our $VERSION = '0.004008'; # VERSION
 
 use Moose::Role;
 with qw(
@@ -12,25 +11,22 @@ with qw(
 	Business::CyberSource::Response::Role::Accept
 );
 
-use MooseX::Types::Moose qw( Num Bool Str Int );
-
-
 has dcc_supported => (
 	required => 1,
 	is       => 'ro',
-	isa      => Bool
+	isa      => 'Bool'
 );
 
 has valid_hours => (
 	required => 1,
 	is       => 'ro',
-	isa      => Int,
+	isa      => 'Int',
 );
 
 has margin_rate_percentage => (
 	required => 1,
 	is       => 'ro',
-	isa      => Num,
+	isa      => 'Num',
 );
 
 1;
@@ -47,7 +43,7 @@ Business::CyberSource::Response::Role::DCC - Role that provides attributes speci
 
 =head1 VERSION
 
-version 0.004007
+version 0.004008
 
 =head1 ATTRIBUTES
 
