@@ -4,16 +4,19 @@ use strict;
 use warnings;
 use namespace::autoclean;
 
-our $VERSION = '0.004007'; # VERSION
+our $VERSION = '0.004008'; # VERSION
 
 use Moose::Role;
+
+use MooseX::SetOnce 0.200001;
+
 use MooseX::Types::CyberSource qw( _VarcharTen );
 
 has processor_response => (
-	required  => 0,
-	predicate => 'has_processor_response',
-	is        => 'ro',
 	isa       => _VarcharTen,
+	predicate => 'has_processor_response',
+	traits    => ['SetOnce'],
+	is        => 'rw',
 );
 
 1;
@@ -30,7 +33,7 @@ Business::CyberSource::Response::Role::ProcessorResponse - Processor Response at
 
 =head1 VERSION
 
-version 0.004007
+version 0.004008
 
 =head1 ATTRIBUTES
 
