@@ -1,22 +1,24 @@
 package Business::CyberSource::Role::ForeignCurrency;
-use 5.008;
 use strict;
 use warnings;
 use namespace::autoclean;
 
-our $VERSION = '0.004007'; # VERSION
+our $VERSION = '0.004008'; # VERSION
 
 use Moose::Role;
+
+use MooseX::SetOnce 0.200001;
+
 use MooseX::Types::Moose            qw( Str );
 use MooseX::Types::Locale::Currency qw( CurrencyCode );
 use MooseX::Types::Common::Numeric  qw( PositiveOrZeroNum );
 
 has foreign_currency => (
-	required  => 0,
-	predicate => 'has_foreign_currency',
-	is        => 'ro',
 	isa       => CurrencyCode,
-	trigger => sub {
+	predicate => 'has_foreign_currency',
+	traits    => ['SetOnce'],
+	is        => 'rw',
+	trigger   => sub {
 		my $self = shift;
 		if ( $self->meta->find_attribute_by_name( '_request_data' ) ) {
 			$self->_request_data->{purchaseTotals}{foreignCurrency}
@@ -24,16 +26,14 @@ has foreign_currency => (
 				;
 		}
 	},
-	documentation => 'Billing currency returned by the DCC service. '
-		. 'For the possible values, see the ISO currency codes',
 );
 
 has foreign_amount => (
+	isa       => PositiveOrZeroNum,
 	predicate => 'has_foreign_amount',
-	required => 0,
-	is       => 'ro',
-	isa      => PositiveOrZeroNum,
-	trigger => sub {
+	traits    => ['SetOnce'],
+	is        => 'rw',
+	trigger   => sub {
 		my $self = shift;
 		if ( $self->meta->find_attribute_by_name( '_request_data' ) ) {
 			$self->_request_data->{purchaseTotals}{foreignAmount}
@@ -44,11 +44,11 @@ has foreign_amount => (
 );
 
 has exchange_rate => (
+	isa       => PositiveOrZeroNum,
 	predicate => 'has_exchange_rate',
-	required => 0,
-	is       => 'ro',
-	isa      => PositiveOrZeroNum,
-	trigger => sub {
+	traits    => ['SetOnce'],
+	is        => 'rw',
+	trigger   => sub {
 		my $self = shift;
 		if ( $self->meta->find_attribute_by_name( '_request_data' ) ) {
 			$self->_request_data->{purchaseTotals}{exchangeRate}
@@ -59,11 +59,11 @@ has exchange_rate => (
 );
 
 has exchange_rate_timestamp => (
+	isa       => Str,
 	predicate => 'has_exchange_rate_timestamp',
-	required => 0,
-	is       => 'ro',
-	isa      => Str,
-	trigger => sub {
+	traits    => ['SetOnce'],
+	is        => 'rw',
+	trigger   => sub {
 		my $self = shift;
 		if ( $self->meta->find_attribute_by_name( '_request_data' ) ) {
 			$self->_request_data->{purchaseTotals}{exchangeRateTimeStamp}
@@ -77,6 +77,7 @@ has exchange_rate_timestamp => (
 
 # ABSTRACT: Role to apply to requests and responses that require currency
 
+
 __END__
 =pod
 
@@ -86,7 +87,13 @@ Business::CyberSource::Role::ForeignCurrency - Role to apply to requests and res
 
 =head1 VERSION
 
-version 0.004007
+version 0.004008
+
+=head1 ATTRIBUTES
+
+=head2 foreign_currency
+
+Billing currency returned by the DCC service. For the possible values, see the ISO currency codes
 
 =head1 BUGS
 
